#
# spec file for package python-smmap
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-smmap
Version:        0.9.0
Release:        5.2
Url:            https://github.com/gitpython-developers/smmap
Summary:        A pure git implementation of a sliding window memory map manager
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/s/smmap/smmap-%{version}.tar.gz
# PATCH-FIX-OPENSUSE delete_platform_specific_test.patch -- fix tests on powerpc
Patch0:         delete_platform_specific_test.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  python-nose
BuildRequires:  python-nosexcover
BuildRequires:  python-setuptools
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
When reading from many possibly large files in a fashion similar to random
access, it is usually the fastest and most efficient to use memory maps.
Although memory maps have many advantages, they represent a very limited
system resource as every map uses one file descriptor, whose amount is
limited per process. On 32 bit systems, the amount of memory you can have
mapped at a time is naturally limited to theoretical 4GB of memory, which
may not be enough for some applications.

The documentation can be found here: http://packages.python.org/smmap

%prep
%setup -q -n smmap-%{version}
%patch0 -p1

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes %{buildroot}/%{_prefix}

%check
python setup.py -q test

%files
%defattr(-,root,root,-)
%{python_sitelib}/*

%changelog
* Tue May  5 2015 benoit.monin@gmx.fr
- update to version 0.9.0:
  * Fixed issue with resources never being freed as mmaps were
    never closed
  * Client counting is now done manually, instead of relying on
    pyton's reference count
- additional changes from version 0.8.5:
  * Fixed Python 3.0-3.3 regression, which also causes smmap to
    become about 3 times slower depending on the code path. It's
    related to this bug (http://bugs.python.org/issue15958), which
    was fixed in python 3.4
- additional changes from version 0.8.4:
  * Fixed Python 3 performance regression
- additional changes from version 0.8.3:
  * Cleaned up code and assured it works sufficiently well with
    python 3
- update project URL
- add fdupes as BuildRequires and call it after install
- add dependencies (nose, nosexcover) for the tests
- add delete_platform_specific_test.patch: fix tests on powerpc
- pass -q to the test to avoid spamming the build log
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Mar 14 2012 saschpe@suse.de
- Use upstream tarball
- Simplified macro usage
- Run testsuite
* Thu Jan 19 2012 alexandre@exatati.com.br
- Update to 0.8.2:
  - Sorry, no changelog yet.
* Wed Jul  6 2011 alexandre@exatati.com.br
- Initial package (0.8.1) for openSUSE.
